@@ -5,14 +5,14 @@ from s2python.generated.gen_s2 import (
 )
 from s2python.validate_values_mixin import (
     catch_and_convert_exceptions,
-    ValidateValuesMixin,
+    S2Message,
 )
 
 
 @catch_and_convert_exceptions
 class FRBCFillLevelTargetProfileElement(
     GenFRBCFillLevelTargetProfileElement,
-    ValidateValuesMixin["FRBCFillLevelTargetProfileElement"],
+    S2Message["FRBCFillLevelTargetProfileElement"],
 ):
     class Config(GenFRBCFillLevelTargetProfileElement.Config):
         validate_assignment = True
